Name:           simavr
Version:        1.7
Release:        3%{?dist}
Summary:        A lean and mean Atmel AVR simulator for Linux

License:        GPLv3
URL:            https://github.com/buserror/%{name}
Source0:        https://github.com/buserror/%{name}/archive/v%{version}/%{name}-%{version}.tar.gz

Patch0:         %{name}-1.7-lib-suffix.patch
Patch1:         %{name}-1.7-static-lib-perms.patch
Patch2:         %{name}-1.7-missing-mkdir.patch
Patch3:         %{name}-1.7-parts-without-examples.patch
Patch4:         %{name}-1.7-no-double-slash.patch
Patch5:         %{name}-1.7-simavrparts-name.patch
Patch6:         %{name}-1.7-simavrparts-lib-util.patch

BuildRequires:  chrpath
BuildRequires:  elfutils-libelf-devel
BuildRequires:  gcc
BuildRequires:  glut-devel
BuildRequires:  make
BuildRequires:  mesa-libGLU-devel

# For tests
BuildRequires:  avr-gcc
BuildRequires:  avr-libc

%description
simavr is a new AVR simulator for Linux, or any platform that uses avr-gcc. It
uses avr-gcc's own register definition to simplify creating new targets for
supported AVR devices. The core was made to be small and compact, and hackable
so allow quick prototyping of an AVR project. The AVR core is now stable for
use with parts with <= 128KB flash, and with preliminary support for the bigger
parts. The simulator loads ELF files directly, and there is even a way to
specify simulation parameters directly in the emulated code using an .elf
section. You can also load multipart HEX files.


%package parts
Summary:        Virtual parts library for simavr
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description parts
Virtual parts library for simavr


%package devel
Summary:        Development files for simavr
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       %{name}-parts%{?_isa} = %{version}-%{release}
Requires:       elfutils-libelf-devel
Requires:       pkgconfig

%description devel
Development files for simavr


%prep
%autosetup -p1


%build
CFLAGS="${CFLAGS:-%optflags}" ; export CFLAGS ;
%{?__global_ldflags:LDFLAGS="${LDFLAGS:-%__global_ldflags}"; export LDFLAGS ; } \
%make_build \
  RELEASE=1 \
  SIMAVR_VERSION=v%{version} \
  build-simavr build-parts build-tests


%install
CFLAGS="${CFLAGS:-%optflags}" ; export CFLAGS ;
%{?__global_ldflags:LDFLAGS="${LDFLAGS:-%__global_ldflags}"; export LDFLAGS ; } \
%make_build \
  PREFIX=%{_prefix} \
  RELEASE=1 \
  SIMAVR_VERSION=v%{version} \
  DESTDIR=%{buildroot}%{_prefix} \
%if "%{?_lib}" == "lib64"
  LIB_SUFFIX=64 \
%endif
  install-simavr install-parts

# Drop the RPATH from the executable
chrpath %{buildroot}%{_bindir}/%{name} -d


%check
%make_build -C tests run_tests


%files
%license COPYING
%doc README.md
%{_bindir}/%{name}
%{_libdir}/lib%{name}.so.*

%files parts
%{_libdir}/lib%{name}parts.so.*

%files devel
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.a
%{_libdir}/lib%{name}.so
%{_libdir}/lib%{name}parts.a
%{_libdir}/lib%{name}parts.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/pkgconfig/%{name}-avr.pc
%{_libdir}/pkgconfig/%{name}parts.pc


%changelog
* Sun Jun 12 2022 Scott K Logan <logans@cottsay.net> - 1.7-3
- Add another missing 'v' prefix to simavr version

* Sun Jun 12 2022 Scott K Logan <logans@cottsay.net> - 1.7-2
- Add missing 'v' prefix to simavr version

* Tue Aug 31 2021 Scott K Logan <logans@cottsay.net> - 1.7-1
- Initial package
